ISystemTimeWithTime Interface

Definition

Namespace: DataStandardizer.Chronology

An ISystemTime that also exposes the hour, minute, and second components of the instant.

public interface ISystemTimeWithTime : ISystemTime

Properties

Property Signature Notes
Hour int Hour { get; } The hour component (0–23).
JulianDayNumber decimal JulianDayNumber { get; } Inherited from ISystemTime.
Minute int Minute { get; } The minute component (0–59).
Second int Second { get; } The second component (0–59).

Applies to

Targets netstandard1.0, netstandard2.0, net8.0, and net10.0.

See also


This site uses Just the Docs, a documentation theme for Jekyll.